.. callHORIZONS documentation master file, created by
   sphinx-quickstart on Sat Feb 27 15:00:03 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CALLHORIZONS Documentation
==========================

CALLHORIZONS is a Python interface to access `JPL HORIZONS`_
ephemerides and orbital elements of Solar System bodies.

**Please note that CALLHORIZONS is not maintained anymore.**
Please use
`astroquery.jplhorizons
<http://astroquery.readthedocs.io/en/latest/jplhorizons/jplhorizons.html>`_
instead, which will be maintained in the future and offers additional
functionality. I apologize for any inconvenience.


.. toctree::
   :maxdepth: 2

   install
   use
   examples
   modules
   

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _JPL HORIZONS: http://ssd.jpl.nasa.gov/horizons.cgi
